fnichol/names

Random name generator for Rust

Rust

155

95 commits

updated Apr 22, 2026

See the code

README


names

Random name generator for Rust

CICI Status
Bors enabled
Latest VersionLatest version
DocumentationDocumentation
Crate DownloadsCrate downloads
GitHub DownloadsGithub downloads
Docker PullsDocker pulls
LicenseCrate license
Table of Contents

CLI

Usage

Simple! Run without any parameters, you get a name:

> names
selfish-change

Need more? Tell it how many:

> names 10
rustic-flag
nondescript-crayon
picayune-map
elderly-cough
skinny-jeans
neat-rock
aware-sponge
psychotic-coast
brawny-event
tender-oatmeal

Not random enough? How about adding a 4-number pad:

> names --number 5
imported-rod-9680
thin-position-2344
hysterical-women-5647
volatile-pen-9210
diligent-grip-4520

If you're ever confused, at least there's help:

> names --help
names 0.11.0
Fletcher Nichol <fnichol@nichol.ca>

A random name generator with results like "delirious-pail"

USAGE:
    names [FLAGS] [AMOUNT]

ARGS:
    <AMOUNT>    Number of names to generate [default: 1]

FLAGS:
    -h, --help       Prints help information
    -n, --number     Adds a random number to the name(s)
    -V, --version    Prints version information

Installation

install.sh (Pre-Built Binaries)

An installer is provided at https://fnichol.github.io/names/install.sh which installs a suitable pre-built binary for common systems such as Linux, macOS, Windows, and FreeBSD. It can be downloaded and run locally or piped into a shell interpreter in the "curl-bash" style as shown below. Note that if you're opposed to this idea, feel free to check some of the alternatives below.

To install the latest release for your system into $HOME/bin:

curl -sSf https://fnichol.github.io/names/install.sh | sh

When the installer is run as root the installation directory defaults to /usr/local/bin:

curl -sSf https://fnichol.github.io/names/install.sh | sudo sh

A nightly release built from HEAD of the main branch is available which can also be installed:

curl -sSf https://fnichol.github.io/names/install.sh \
    | sh -s -- --release=nightly

For a full set of options, check out the help usage with:

curl -sSf https://fnichol.github.io/names/install.sh | sh -s -- --help

GitHub Releasees (Pre-Built Binaries)

Each release comes with binary artifacts published in GitHub Releases. The install.sh program downloads its artifacts from this location so this serves as a manual alternative. Each artifact ships with MD5 and SHA256 checksums to help verify the artifact on a target system.

Docker Image

A minimal image ships with each release (including a nightly built version from HEAD of the main branch) published to Docker Hub. The entrypoint invokes the binary directly, so any arguments to docker run will be passed to the program. For example, to display the full help usage:

docker run fnichol/names --help

Cargo Install

If Rust is installed on your system, then installing with Cargo is straight forward with:

cargo install names

From Source

To install from source, you can clone the Git repository, build with Cargo and copy the binary into a destination directory. This will build the project from the latest commit on the main branch, which may not correspond to the latest stable release:

> git clone https://github.com/fnichol/names.git
> cd names
> cargo build --release
> cp ./target/release/names /dest/path/

Library

This crate provides a generate that constructs random name strings suitable for use in container instances, project names, application instances, etc.

The name Generator implements the Iterator trait so it can be used with adapters, consumers, and in loops.

Usage

This crate is on crates.io and can be used by adding names to your dependencies in your project's Cargo.toml file:

[dependencies]
names = { version = "0.14.0", default-features = false }

Examples

Example: painless defaults

The easiest way to get started is to use the default Generator to return a name:

use names::Generator;

let mut generator = Generator::default();
println!("Your project is: {}", generator.next().unwrap());
// #=> "Your project is: rusty-nail"

If more randomness is required, you can generate a name with a trailing 4-digit number:

use names::{Generator, Name};

let mut generator = Generator::with_naming(Name::Numbered);
println!("Your project is: {}", generator.next().unwrap());
// #=> "Your project is: pushy-pencil-5602"

Example: with custom dictionaries

If you would rather supply your own custom adjective and noun word lists, you can provide your own by supplying 2 string slices. For example, this returns only one result:

use names::{Generator, Name};

let adjectives = &["imaginary"];
let nouns = &["roll"];
let mut generator = Generator::new(adjectives, nouns, Name::default());

assert_eq!("imaginary-roll", generator.next().unwrap());

CI Status

Build (main branch)

Operating SystemTargetStable Rust
FreeBSDx86_64-unknown-freebsdFreeBSD Build Status
Linuxarm-unknown-linux-gnueabihfLinux Build Status
Linuxaarch64-unknown-linux-gnuLinux Build Status
Linuxi686-unknown-linux-gnuLinux Build Status
Linuxi686-unknown-linux-muslLinux Build Status
Linuxx86_64-unknown-linux-gnuLinux Build Status
Linuxx86_64-unknown-linux-muslLinux Build Status
macOSx86_64-apple-darwinmacOS Build Status
Windowsx86_64-pc-windows-msvcWindows Build Status

Test (main branch)

Operating SystemStable RustNightly Rust
FreeBSDFreeBSD Stable Test StatusFreeBSD Nightly Test Status
LinuxLinux Stable Test StatusLinux Nightly Test Status
macOSmacOS Stable Test StatusmacOS Nightly Test Status
WindowsWindows Stable Test StatusWindows Nightly Test Status

Note: The Minimum Supported Rust Version (MSRV) is also tested and can be viewed in the CI dashboard.

Check (main branch)

Status
LintLint Status
FormatFormat Status

Code of Conduct

This project adheres to the Contributor Covenant code of conduct. By participating, you are expected to uphold this code. Please report unacceptable behavior to fnichol@nichol.ca.

Issues

If you have any problems with or questions about this project, please contact us through a GitHub issue.

Contributing

You are invited to contribute to new features, fixes, or updates, large or small; we are always thrilled to receive pull requests, and do our best to process them as fast as we can.

Before you start to code, we recommend discussing your plans through a GitHub issue, especially for more ambitious contributions. This gives other contributors a chance to point you in the right direction, give you feedback on your design, and help you find out if someone else is working on the same thing.

Release History

See the changelog for a full release history.

Authors

Created and maintained by Fletcher Nichol (fnichol@nichol.ca).

License

Licensed under the MIT license (LICENSE.txt).

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the MIT license, shall be licensed as above, without any additional terms or conditions.

Project health

Overall

2.5/10

Maintained

0/10

Code review

6/10
OpenSSF Scorecard

crates.io

Latest release

0.14.0 · Jun 28, 2022

Releases this year

0

Significant stargazers

David Bottiau

94 followers · starred Mar 2024

Juncen Yu

41 followers · starred Oct 2019

FuXiaoHei

607 followers · starred Apr 2023

Dom Rodriguez

131 followers · starred Nov 2023

fnichol/names

Random name generator for Rust

Rust

155

95 commits

updated Apr 22, 2026

See the code

README


names

Random name generator for Rust

CICI Status
Bors enabled
Latest VersionLatest version
DocumentationDocumentation
Crate DownloadsCrate downloads
GitHub DownloadsGithub downloads
Docker PullsDocker pulls
LicenseCrate license
Table of Contents

CLI

Usage

Simple! Run without any parameters, you get a name:

> names
selfish-change

Need more? Tell it how many:

> names 10
rustic-flag
nondescript-crayon
picayune-map
elderly-cough
skinny-jeans
neat-rock
aware-sponge
psychotic-coast
brawny-event
tender-oatmeal

Not random enough? How about adding a 4-number pad:

> names --number 5
imported-rod-9680
thin-position-2344
hysterical-women-5647
volatile-pen-9210
diligent-grip-4520

If you're ever confused, at least there's help:

> names --help
names 0.11.0
Fletcher Nichol <fnichol@nichol.ca>

A random name generator with results like "delirious-pail"

USAGE:
    names [FLAGS] [AMOUNT]

ARGS:
    <AMOUNT>    Number of names to generate [default: 1]

FLAGS:
    -h, --help       Prints help information
    -n, --number     Adds a random number to the name(s)
    -V, --version    Prints version information

Installation

install.sh (Pre-Built Binaries)

An installer is provided at https://fnichol.github.io/names/install.sh which installs a suitable pre-built binary for common systems such as Linux, macOS, Windows, and FreeBSD. It can be downloaded and run locally or piped into a shell interpreter in the "curl-bash" style as shown below. Note that if you're opposed to this idea, feel free to check some of the alternatives below.

To install the latest release for your system into $HOME/bin:

curl -sSf https://fnichol.github.io/names/install.sh | sh

When the installer is run as root the installation directory defaults to /usr/local/bin:

curl -sSf https://fnichol.github.io/names/install.sh | sudo sh

A nightly release built from HEAD of the main branch is available which can also be installed:

curl -sSf https://fnichol.github.io/names/install.sh \
    | sh -s -- --release=nightly

For a full set of options, check out the help usage with:

curl -sSf https://fnichol.github.io/names/install.sh | sh -s -- --help

GitHub Releasees (Pre-Built Binaries)

Each release comes with binary artifacts published in GitHub Releases. The install.sh program downloads its artifacts from this location so this serves as a manual alternative. Each artifact ships with MD5 and SHA256 checksums to help verify the artifact on a target system.

Docker Image

A minimal image ships with each release (including a nightly built version from HEAD of the main branch) published to Docker Hub. The entrypoint invokes the binary directly, so any arguments to docker run will be passed to the program. For example, to display the full help usage:

docker run fnichol/names --help

Cargo Install

If Rust is installed on your system, then installing with Cargo is straight forward with:

cargo install names

From Source

To install from source, you can clone the Git repository, build with Cargo and copy the binary into a destination directory. This will build the project from the latest commit on the main branch, which may not correspond to the latest stable release:

> git clone https://github.com/fnichol/names.git
> cd names
> cargo build --release
> cp ./target/release/names /dest/path/

Library

This crate provides a generate that constructs random name strings suitable for use in container instances, project names, application instances, etc.

The name Generator implements the Iterator trait so it can be used with adapters, consumers, and in loops.

Usage

This crate is on crates.io and can be used by adding names to your dependencies in your project's Cargo.toml file:

[dependencies]
names = { version = "0.14.0", default-features = false }

Examples

Example: painless defaults

The easiest way to get started is to use the default Generator to return a name:

use names::Generator;

let mut generator = Generator::default();
println!("Your project is: {}", generator.next().unwrap());
// #=> "Your project is: rusty-nail"

If more randomness is required, you can generate a name with a trailing 4-digit number:

use names::{Generator, Name};

let mut generator = Generator::with_naming(Name::Numbered);
println!("Your project is: {}", generator.next().unwrap());
// #=> "Your project is: pushy-pencil-5602"

Example: with custom dictionaries

If you would rather supply your own custom adjective and noun word lists, you can provide your own by supplying 2 string slices. For example, this returns only one result:

use names::{Generator, Name};

let adjectives = &["imaginary"];
let nouns = &["roll"];
let mut generator = Generator::new(adjectives, nouns, Name::default());

assert_eq!("imaginary-roll", generator.next().unwrap());

CI Status

Build (main branch)

Operating SystemTargetStable Rust
FreeBSDx86_64-unknown-freebsdFreeBSD Build Status
Linuxarm-unknown-linux-gnueabihfLinux Build Status
Linuxaarch64-unknown-linux-gnuLinux Build Status
Linuxi686-unknown-linux-gnuLinux Build Status
Linuxi686-unknown-linux-muslLinux Build Status
Linuxx86_64-unknown-linux-gnuLinux Build Status
Linuxx86_64-unknown-linux-muslLinux Build Status
macOSx86_64-apple-darwinmacOS Build Status
Windowsx86_64-pc-windows-msvcWindows Build Status

Test (main branch)

Operating SystemStable RustNightly Rust
FreeBSDFreeBSD Stable Test StatusFreeBSD Nightly Test Status
LinuxLinux Stable Test StatusLinux Nightly Test Status
macOSmacOS Stable Test StatusmacOS Nightly Test Status
WindowsWindows Stable Test StatusWindows Nightly Test Status

Note: The Minimum Supported Rust Version (MSRV) is also tested and can be viewed in the CI dashboard.

Check (main branch)

Status
LintLint Status
FormatFormat Status

Code of Conduct

This project adheres to the Contributor Covenant code of conduct. By participating, you are expected to uphold this code. Please report unacceptable behavior to fnichol@nichol.ca.

Issues

If you have any problems with or questions about this project, please contact us through a GitHub issue.

Contributing

You are invited to contribute to new features, fixes, or updates, large or small; we are always thrilled to receive pull requests, and do our best to process them as fast as we can.

Before you start to code, we recommend discussing your plans through a GitHub issue, especially for more ambitious contributions. This gives other contributors a chance to point you in the right direction, give you feedback on your design, and help you find out if someone else is working on the same thing.

Release History

See the changelog for a full release history.

Authors

Created and maintained by Fletcher Nichol (fnichol@nichol.ca).

License

Licensed under the MIT license (LICENSE.txt).

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the MIT license, shall be licensed as above, without any additional terms or conditions.

Project health

Overall

2.5/10

Maintained

0/10

Code review

6/10
OpenSSF Scorecard

crates.io

Latest release

0.14.0 · Jun 28, 2022

Releases this year

0

Significant stargazers

David Bottiau

94 followers · starred Mar 2024

Juncen Yu

41 followers · starred Oct 2019

FuXiaoHei

607 followers · starred Apr 2023

Dom Rodriguez

131 followers · starred Nov 2023